==> haskell-skylighting-format-latex-0.1-282.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-latex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-latex
version:              0.1
visibility:           public
id:                   skylighting-format-latex-0.1-BoRYPHSlljI9lBjbXNf1qi
key:                  skylighting-format-latex-0.1-BoRYPHSlljI9lBjbXNf1qi
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             LaTeX formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as LaTeX macros.

category:             Text
abi:                  fc613ba3fa110189775804c56993d5e6
exposed:              True
exposed-modules:      Skylighting.Format.LaTeX
import-dirs:          /usr/lib/ghc-9.6.6/site-local/skylighting-format-latex-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/skylighting-format-latex-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/skylighting-format-latex-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-latex
hs-libraries:         HSskylighting-format-latex-0.1-BoRYPHSlljI9lBjbXNf1qi
depends:
    base-4.18.2.1 containers-0.6.7
    skylighting-core-0.14.3-Doguo3BFqgg4PCTJ9olxvN text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-latex/html/skylighting-format-latex.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-latex/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-skylighting-format-latex-0.1-284-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-skylighting-format-latex.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 skylighting-format-latex
version:              0.1
visibility:           public
id:                   skylighting-format-latex-0.1-8KUzTwYUJ8z1YDNm3yTUKd
key:                  skylighting-format-latex-0.1-8KUzTwYUJ8z1YDNm3yTUKd
license:              BSD-3-Clause
copyright:            (C) 2016-2022 John MacFarlane
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             https://github.com/jgm/skylighting
synopsis:             LaTeX formatter for skylighting syntax highlighting library
description:
    This module allows tokens produced by skylighting-core
    to be rendered as LaTeX macros.

category:             Text
abi:                  24b06ad390b42308b57e447d173de678
exposed:              True
exposed-modules:      Skylighting.Format.LaTeX
import-dirs:          /usr/lib/ghc-9.6.6/site-local/skylighting-format-latex-0.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/skylighting-format-latex-0.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/skylighting-format-latex-0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-skylighting-format-latex
hs-libraries:         HSskylighting-format-latex-0.1-8KUzTwYUJ8z1YDNm3yTUKd
depends:
    base-4.18.2.1 containers-0.6.7
    skylighting-core-0.14.3-2rZAIOUbaN91Pp7XWprJjv text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-skylighting-format-latex/html/skylighting-format-latex.haddock

haddock-html:         /usr/share/doc/haskell-skylighting-format-latex/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
